import { Stack } from 'aws-cdk-lib';
import { MermaidDiagramOutput } from './shared';
export interface IExpressStageLegacy {
    /**
     * The stage identifier
     */
    id: string;
    /**
     * The stacks in the stage
     */
    stacks: Stack[];
}
/**
 * A stage that holds stacks
 */
export declare class ExpressStageLegacy implements IExpressStageLegacy {
    id: string;
    stacks: Stack[];
    constructor(id: string, stacks?: Stack[]);
    /**
     * Add a stack to the stage
     * @param stack The stack to add
     */
    addStack(stack: Stack): Stack;
}
export interface IExpressWaveLegacy {
    /**
     * The wave identifier
     */
    id: string;
    /**
     * The ExpressStages in the wave
     */
    stages: IExpressStageLegacy[];
    /**
     * If true, the stages in the wave will be executed sequentially
     * @default false
     */
    sequentialStages?: boolean;
}
/**
 * A CDK Express Pipeline Legacy Wave that contains Legacy Stages
 */
export declare class ExpressWaveLegacy implements IExpressWaveLegacy {
    id: string;
    stages: IExpressStageLegacy[];
    sequentialStages?: boolean;
    /**
     * Constructs a new instance of the ExpressWaveLegacy class
     * @param id
     * @param sequentialStages If true, the stages in the wave will be executed sequentially. Default: false.
     */
    constructor(id: string, sequentialStages?: boolean);
    /**
     * Add a stage to the wave
     * @param id The stage identifier
     */
    addStage(id: string): ExpressStageLegacy;
}
/**
 * A CDK Express Pipeline that defines the order in which the stacks are deployed.
 *
 * This is the legacy version of the pipeline that uses the `Stack` class, for plug and play compatibility with existing CDK projects that can not
 * use the `ExpressStack` class. For new projects, use the `CdkExpressPipeline` class.
 */
export declare class CdkExpressPipelineLegacy {
    waves: IExpressWaveLegacy[];
    constructor(waves?: IExpressWaveLegacy[]);
    /** Add a wave to the pipeline
     * @param id The wave identifier
     * @param sequentialStages If true, the stages in the wave will be executed sequentially. Default: false.
     */
    addWave(id: string, sequentialStages?: boolean): ExpressWaveLegacy;
    /** Synthesize the pipeline which creates the dependencies between the stacks in the correct order
     * @param waves The waves to synthesize
     * @param print Whether to print the order of deployment to the console
     * @param saveMermaidDiagram If provided, saves a Mermaid diagram of the deployment order to the specified path
     */
    synth(waves?: IExpressWaveLegacy[], print?: boolean, saveMermaidDiagram?: MermaidDiagramOutput): void;
    /**
     * Print the order of deployment to the console
     * @param waves
     */
    printWaves(waves: IExpressWaveLegacy[]): void;
    /**
     * Calculate deployment order numbers for stacks within a stage
     * @param stacks The stacks in the stage
     * @private
     */
    private calculateStackOrderNumbers;
    /**
     * Generate a Mermaid diagram showing the deployment order
     * @param waves The waves to include in the diagram
     * @private
     */
    generateMermaidDiagram(waves: IExpressWaveLegacy[]): string;
}
export default CdkExpressPipelineLegacy;
