import { ExpressWave, IExpressWave } from './express-wave';
import { MermaidDiagramOutput } from './shared';
export declare const CDK_EXPRESS_PIPELINE_DEPENDENCY_REASON = "cdk-express-pipeline wave->stage->stack dependency";
export declare const CDK_EXPRESS_PIPELINE_DEFAULT_SEPARATOR = "_";
export interface CdkExpressPipelineProps {
    /**
     * The waves in the pipeline
     */
    readonly waves?: ExpressWave[];
    /** Separator between the wave, stage and stack ids that are concatenated to form the stack id
     * @default _ */
    readonly separator?: string;
}
/**
 * A CDK Express Pipeline that defines the order in which the stacks are deployed
 */
export declare class CdkExpressPipeline {
    readonly waves: IExpressWave[];
    private separator;
    constructor(props?: CdkExpressPipelineProps);
    /** Add a wave to the pipeline
     * @param id The wave identifier
     * @param sequentialStages If true, the stages in the wave will be executed sequentially. Default: false.
     */
    addWave(id: string, sequentialStages?: boolean): IExpressWave;
    /** Synthesize the pipeline which creates the dependencies between the stacks in the correct order
     * @param waves The waves to synthesize
     * @param print Whether to print the order of deployment to the console
     * @param saveMermaidDiagram If provided, saves a Mermaid diagram of the deployment order to the specified path
     */
    synth(waves?: IExpressWave[], print?: boolean, saveMermaidDiagram?: MermaidDiagramOutput): void;
    /**
     * Print the order of deployment to the console
     * @param waves
     * @private
     */
    printWaves(waves: IExpressWave[]): void;
    /**
     * Calculate deployment order numbers for stacks within a stage
     * @param stacks The stacks in the stage
     * @private
     */
    private calculateStackOrderNumbers;
    /**
     * Generate a Mermaid diagram showing the deployment order
     * @param waves The waves to include in the diagram
     * @private
     */
    generateMermaidDiagram(waves: IExpressWave[]): string;
}
export default CdkExpressPipeline;
